#ifndef __CARET_COMMAND_LINE_H__
#define __CARET_COMMAND_LINE_H__

/*LICENSE_START*/
/*
 *  Copyright (C) 2014  Washington University School of Medicine
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with this program; if not, write to the Free Software Foundation, Inc.,
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
/*LICENSE_END*/

#include "AString.h"

namespace caret {
    
    class ProgramParameters;
    
    extern AString caret_global_commandLine;
    
    void caret_global_commandLine_init(const ProgramParameters& params);
    
    void caret_global_commandLine_init(const int& argc, const char *const * argv);
    
}

#endif //__CARET_COMMAND_LINE_H__
